@@ -718,7 +718,7 @@ class Menu(py.sprite.Group):
     classe principale du Menu
     """
 
-    def __init__(self, name, manager: Menu_Manager, parent: str = None, childs: Union[list[str], str] = None, background: str = None):
+    def __init__(self, name, manager, parent= None, childs = None, background = None):
         super().__init__()
         self.name: str = name
         self.parent: str = parent
